"use client";

import { getStorage, setStorage } from "@/utils/navigation";
import { Box } from "@chakra-ui/react";
import { useEffect, useState, useCallback } from "react";
import CardList from "./components/card-list";
import { CardListProps } from "../kycs/components/card-list";
import { dcFormsRequestList } from "@/app/lib/dc/actions";

export interface DCData {
  last_sync_at: string;
  data: CardListProps[];
}

const Page = () => {
  const [data, setData] = useState([]);
  const [loading, setLoading] = useState<boolean>(false);

  const handleSync = useCallback(async () => {
    setLoading(true);
    setStorage("dcs", null);
    try {
      const res = await dcFormsRequestList({ pagination: "false" });
      const syncData: DCData = {
        last_sync_at: new Date().toISOString(),
        data: res?.data || [],
      };

      setStorage("dcs", syncData);
      setData(syncData.data);
    } catch (error) {
      console.error("Error syncing dc forms:", error);
    } finally {
      setLoading(false);
    }
  }, []);

  useEffect(() => {
    const getAllDCForms = async () => {
      setLoading(true);
      try {
        const storedData = await getStorage("dcs");
        const isDataStale =
          !storedData?.last_sync_at ||
          Date.now() - new Date(storedData.last_sync_at).getTime() > 86400000;

        if (
          (storedData?.data && !isDataStale) ||
          storedData?.data?.some(
            (item: { offline: Boolean }) => item?.offline == true
          )
        ) {
          setData(storedData.data);
        } else {
          await handleSync();
        }
      } catch (error) {
        console.error("Error fetching dc forms:", error);
      } finally {
        setLoading(false);
      }
    };

    getAllDCForms();
  }, []);

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      <CardList data={data} isLoading={loading} handleSync={handleSync} />
    </Box>
  );
};

export default Page;
